!function(_,t){"object"==typeof exports&&"undefined"!=typeof module?module.exports=t(require("dayjs")):"function"==typeof define&&define.amd?define(["dayjs"],t):(_="undefined"!=typeof globalThis?globalThis:_||self).dayjs_locale_be=t(_.dayjs)}(this,(function(_){"use strict";function t(_){return _&&"object"==typeof _&&"default"in _?_:{default:_}}var e=t(_),n="студзеня_лютага_сакавіка_красавіка_траўня_чэрвеня_ліпеня_жніўня_верасня_кастрычніка_лістапада_снежня".split("_"),s="студзень_лютый_сакавік_красавік_травень_чэрвень_ліпень_жнівень_верасень_кастрычнік_лістапад_снежань".split("_"),o="студ_лют_сак_крас_трав_чэрв_ліп_жнів_вер_каст_ліст_снеж.".split("_"),i="студ_лют_сак_крас_трав_чэрв_ліп_жнів_вер_каст_ліст_снеж".split("_"),r=/D[oD]?(\[[^[\]]*\]|\s)+MMMM?/;function d(_,t,e){var n,s;return"m"===e?t?"хвіліна":"хвіліну":"h"===e?t?"гадзіна":"гадзіну":_+" "+(n=+_,s={ss:t?"секунда_секунды_секунд":"секунду_секунды_секунд",mm:t?"хвіліна_хвіліны_хвілін":"хвіліну_хвіліны_хвілін",hh:t?"гадзіна_гадзіны_гадзін":"гадзіну_гадзіны_гадзін",dd:"дзень_дні_дзён",MM:"месяц_месяцы_месяцаў",yy:"год_гады_гадоў"}[e].split("_"),n%10==1&&n%100!=11?s[0]:n%10>=2&&n%10<=4&&(n%100<10||n%100>=20)?s[1]:s[2])}var a=function(_,t){return r.test(t)?n[_.month()]:s[_.month()]};a.s=s,a.f=n;var m=function(_,t){return r.test(t)?o[_.month()]:i[_.month()]};m.s=i,m.f=o;var u={name:"be",weekdays:"нядзеля_панядзелак_аўторак_серада_чацвер_пятніца_субота".split("_"),weekdaysShort:"няд_пнд_аўт_сер_чцв_пят_суб".split("_"),weekdaysMin:"нд_пн_аў_ср_чц_пт_сб".split("_"),months:a,monthsShort:m,weekStart:1,yearStart:4,formats:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD.MM.YYYY",LL:"D MMMM YYYY г.",LLL:"D MMMM YYYY г., HH:mm",LLLL:"dddd, D MMMM YYYY г., HH:mm"},relativeTime:{future:"праз %s",past:"%s таму",s:"некалькі секунд",m:d,mm:d,h:d,hh:d,d:"дзень",dd:d,M:"месяц",MM:d,y:"год",yy:d},ordinal:function(_){return _},meridiem:function(_){return _<4?"ночы":_<12?"раніцы":_<17?"дня":"вечара"}};return e.default.locale(u,null,!0),u}));